Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3606)

Unified Diff: chrome/browser/ui/views/tabs/dragged_tab_controller.h

Issue 4694008: Make pink's TabContentsWrapper change compile on Windows.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/tabs/dragged_tab_controller.h
===================================================================
--- chrome/browser/ui/views/tabs/dragged_tab_controller.h (revision 66453)
+++ chrome/browser/ui/views/tabs/dragged_tab_controller.h (working copy)
@@ -11,6 +11,7 @@
#include "base/timer.h"
#include "chrome/browser/dock_info.h"
#include "chrome/browser/tab_contents/tab_contents_delegate.h"
+#include "chrome/browser/tab_contents_wrapper.h"
#include "chrome/common/notification_observer.h"
#include "chrome/common/notification_registrar.h"
#include "gfx/rect.h"
@@ -67,7 +68,7 @@
// begun.
void EndDrag(bool canceled);
- TabContents* dragged_contents() { return dragged_contents_; }
+ TabContentsWrapper* dragged_contents() { return dragged_contents_; }
// Returns true if a drag started.
bool started_drag() const { return started_drag_; }
@@ -141,7 +142,7 @@
void UpdateDockInfo(const gfx::Point& screen_point);
// Sets the TabContents being dragged with the specified |new_contents|.
- void SetDraggedContents(TabContents* new_contents);
+ void SetDraggedContents(TabContentsWrapper* new_contents);
// Saves focus in the window that the drag initiated from. Focus will be
// restored appropriately if the drag ends within this same window.
@@ -241,8 +242,8 @@
// Handles registering for notifications.
NotificationRegistrar registrar_;
- // The TabContents being dragged.
- TabContents* dragged_contents_;
+ // The TabContentsWrapper being dragged.
+ TabContentsWrapper* dragged_contents_;
// The original TabContentsDelegate of |dragged_contents_|, before it was
// detached from the browser window. We store this so that we can forward

Powered by Google App Engine
This is Rietveld 408576698